from distutils.core import setup
setup(
name = 'helloWorldFredyTrees',
version = '1.0.0',
py_modules = ['helloWorld'],
author = 'namanyafredy',
author_email = 'gausah@yahoo.com',
url = 'http://www.treessolutions.com',
description = 'Latihan python,padahal consultant oracle',
)